from netforce.model import Model, fields, get_model
from netforce.access import get_active_company

class PatientType(Model):
    _name="clinic.patient.type"
    _string="Patient Type"
    _key=['code','name']
    _multi_company=True
    _fields={
        "name": fields.Char("Name",required=True,search=True),
        "code": fields.Char("Code",required=True,search=True),
        'contact_id': fields.Many2One("partner","Contact",domain=[['type','=','org']],search=True),
        'default': fields.Boolean("Default"),
        'hct_include': fields.Boolean("HCT Include"),
        'main_product': fields.Boolean("Use Main Product for Create GI"),
        'company_id': fields.Many2One("company","Company"),
        #'color': fields.Char("Color"),
        'color': fields.Selection([['default','Default'],['danger','Danger'],['info','Info'],['warning','Warning'],['primary','Primary']],"Color"),
    }
    
    _defaults={
        'defaults': False,
        'company_id': lambda *a: get_active_company(),
        'color': 'default',
    } 

    def new_contact(self,ids,context={}):
        obj=self.browse(ids)[0]
        code=obj.code or ""
        name=obj.name or ""
        pids=get_model("partner").search([['code','=',code]])
        if not pids:
            vals={
                'name': name,
                'code': code,
                'customer': True,
                'type': 'org',
            }
            new_contact_id=get_model("partner").create(vals)
            obj.write({
                'contact_id': new_contact_id,
            })
        return {
            'next': {
                'name': 'contact',
                'mode': 'form',
                'active_id': new_contact_id,
            },
            'flash': 'Create contact succesfully, please config Account Fee, Medecine and Service on tab Accounting.',
        }
    
    def write(self,ids,vals,**kw):
        default=vals.get('default')
        if default:
            for obj in self.search_browse([]):
                if obj.id not in ids:
                    obj.write({
                        'default': False,
                    })
        super().write(ids,vals,**kw)

PatientType.register()
